@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Page;
 BEGIN {
-  $Mojito::Page::VERSION = '0.09';
+  $Mojito::Page::VERSION = '0.10';
 }
 use Moo;
 use Sub::Quote qw(quote_sub);
@@ -26,8 +26,10 @@ use Mojito::Page::Parse;
 use Mojito::Page::Render;
 use Mojito::Page::CRUD;
 use Mojito::Page::Git;
+use Mojito::Page::Publish;
 use Mojito::Template;
 use Mojito::Model::Link;
+use Mojito::Collection::CRUD;
 
 # roles
 
@@ -70,6 +72,13 @@ has editer => (
     writer => '_build_edit',
 );
 
+has collector => (
+    is      => 'ro',
+    isa     => sub { die "Need a Collection::CRUD object" unless $_[0]->isa('Mojito::Collection::CRUD') },
+    handles => [ qw( ) ],
+    writer => '_build_collect',
+);
+
 has tmpl => (
     is      => 'ro',
     isa     => sub { die "Need a Template object" unless $_[0]->isa('Mojito::Template') },
@@ -77,6 +86,11 @@ has tmpl => (
         qw(
           template
           home_page
+          recent_links
+          collect_page_form
+          collections_index
+          collection_page
+          sort_collection_form
           fillin_create_page
           fillin_edit_page
           )
@@ -91,6 +105,7 @@ has linker => (
         qw(
             get_most_recent_links
             get_feed_links
+            view_collections_index
           )
     ],
     writer => '_build_link',
@@ -107,8 +122,16 @@ has gitter => (
             search_word
           )
     ],
-    writer => '_build_gitter',
+    writer => '_build_git',
 );
+
+has publisher => (
+    is      => 'ro',
+    isa     => sub { die "Need a PagePublish object" unless $_[0]->isa('Mojito::Page::Publish') },
+    handles => [ qw( ) ],
+    writer => '_build_publish',
+);
+
 =head1 Methods
 
 =head2 BUILD
@@ -125,10 +148,11 @@ sub BUILD {
     $self->_build_parse(Mojito::Page::Parse->new($constructor_args_href));
     $self->_build_render(Mojito::Page::Render->new($constructor_args_href));
     $self->_build_edit(Mojito::Page::CRUD->new( $constructor_args_href));
-    $self->_build_gitter(Mojito::Page::Git->new( $constructor_args_href));
+    $self->_build_collect(Mojito::Collection::CRUD->new( $constructor_args_href));
+    $self->_build_git(Mojito::Page::Git->new( $constructor_args_href));
     $self->_build_template(Mojito::Template->new( $constructor_args_href));
     $self->_build_link(Mojito::Model::Link->new( $constructor_args_href));
-
+    $self->_build_publish(Mojito::Page::Publish->new( $constructor_args_href));
 }
 
 1
\ No newline at end of file
