@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Role::DB;
 BEGIN {
-  $Mojito::Role::DB::VERSION = '0.09';
+  $Mojito::Role::DB::VERSION = '0.10';
 }
 use Moo::Role;
 use MongoDB;
@@ -16,21 +16,25 @@ has 'db_name' => (
     is => 'rw',
     lazy => 1,
     default => sub { 'mojito' },
+    clearer => 'clear_db_name',
 );
 has 'db' => (
     is => 'ro',
     lazy => 1,
     builder => '_build_db',
+    clearer => 'clear_db',
 );
 has 'collection' => (
     is => 'ro',
     lazy => 1,
     builder => '_build_collection',
+    clearer => 'clear_collection',
 );
 has 'collection_name' => (
     is => 'rw',
     lazy => 1,
     default => sub { 'notes' },
+    clearer => 'clear_collection_name',
 );
 
 sub _build_conn {
@@ -47,4 +51,17 @@ sub _build_collection  {
     my $collection_name = $self->collection_name;
     $self->db->${collection_name};
 }
+
+=head1 Methods
+
+=head2 BUILD
+
+Set a test DB when RELEASE_TESTING
+
+=cut
+
+sub BUILD {
+    my ($self) = (shift);
+    $self->db_name('mojito_test') if $ENV{RELEASE_TESTING};
+}
 1;
\ No newline at end of file
