@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Template::Role::CSS;
 BEGIN {
-  $Mojito::Template::Role::CSS::VERSION = '0.09';
+  $Mojito::Template::Role::CSS::VERSION = '0.10';
 }
 use Moo::Role;
 use Mojito::Types;
@@ -18,8 +18,8 @@ has css => (
 sub _build_css {
     [
       'css/ui-lightness/jquery-ui-1.8.11.custom.css',
-      'syntax_highlight/prettify.css',
-      'SHJS/sh_rand01.min.css',
+      'syntax_highlight/prettify_mojito.css',
+      'SHJS/sh_mojito.css',
       'css/mojito.css',
     ];
 }
